UserSpaceApi class

Bilibili user space API

Constructors

UserSpaceApi(BiliHttpClient client)

Properties

client BiliHttpClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllUserVideos(int mid, {String order = UserVideoOrder.pubdate, int maxPages = 100, int ps = 30}) Future<List<UploadedVideo>>
Get all user videos with pagination
getUserVideos(int mid, {String order = UserVideoOrder.pubdate, int tid = 0, String? keyword, int pn = 1, int ps = 30}) Future<UserUploadVideos>
Get user's uploaded videos
getUserVideosByCategory(int mid, int tid, {String order = UserVideoOrder.pubdate, int pn = 1, int ps = 30}) Future<UserUploadVideos>
Get user videos by category
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
searchUserVideos(int mid, String keyword, {String order = UserVideoOrder.pubdate, int pn = 1, int ps = 30}) Future<UserUploadVideos>
Search user's uploaded videos
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited