VideoPage class

Video page (分P) information

Constructors

VideoPage({required int cid, required int page, required String from, required String part, required int duration, VideoDimension? dimension})
VideoPage.fromJson(Map<String, dynamic> json)
factory

Properties

cid int
final
dimension VideoDimension?
final
duration int
final
from String
final
hashCode int
The hash code for this object.
no setterinherited
page int
final
part String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited