VideoUrl class

Video URL segment (for MP4/FLV)

Constructors

VideoUrl({required int order, required int length, required int size, required String url, List<String>? backupUrl})
VideoUrl.fromJson(Map<String, dynamic> json)
factory

Properties

backupUrl List<String>?
final
hashCode int
The hash code for this object.
no setterinherited
length int
final
order int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
final
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited