VideoPage class
Video page (分P) information
Constructors
- VideoPage({required int cid, required int page, required String from, required String part, required int duration, VideoDimension? dimension})
-
VideoPage.fromJson(Map<
String, dynamic> json) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited